@@ -141,7 +141,7 @@ class RefuelClient:
         if validate_data:
             schema = self._init_context.get("schemas", {}).get(model_name, {})
             if schema:
-                validate_event_schema(event, schema)
+                validate_event_schema(json.loads(event.serialize()), schema)
             else:
                 logger.info(f"No model schema found. Skipping data validation.")
         return self._post(url=self._api_base_url + "/log", body=event.serialize())
@@ -378,6 +378,8 @@ class RefuelClient:
         self,
         model_name: str,
         queue_name: str = DEFAULT_QUEUE_NAME,
+        sampling_job: str = None,
+        user: str = None,
         time_start: str = DATE_FOURTEEN_DAYS_AGO,
         time_end: str = DATE_TOMORROW,
         filters: List[Dict] = [],
@@ -405,6 +407,10 @@ class RefuelClient:
             "max_events": max_events,
             "filters": json.dumps(filters),
         }
+        if sampling_job:
+            params["sampling_job"] = sampling_job
+        if user:
+            params["user"] = user
         return self._query_helper(
             url=self._api_base_url + "/query_annotation_queue",
             params=params,
